@@ -147,7 +147,8 @@ class BaseDao(object):
             return session.query(self.entry).filter_by(**where_dict)
         return session.query(self.entry)
 
-    def filter_fetch(self,query,limit=None, offset=None, page=None, per_page=None,order_by=None,count=None,**kwargs):
+    def filter_fetch(self, query, limit=None, offset=None, page=None, per_page=None, order_by=None, count=None,
+                     **kwargs):
         """
         :param query:
         :param limit:
@@ -219,7 +220,7 @@ class BaseDao(object):
                 q = session.query(self.entry)
         else:
             q = session.query(self.entry)
-        res = self.filter_fetch(q,**kwargs)
+        res = self.filter_fetch(q, **kwargs)
         self.tr.end()
         return res
 
@@ -239,12 +240,12 @@ class BaseDao(object):
                 else:
                     orders.append(getattr(getattr(join_entry, k), v)())
             temp = temp.order_by(*orders)
-        res = self.filter_fetch(temp,**kwargs)
+        res = self.filter_fetch(temp, **kwargs)
         self.tr.end()
         return res
 
     def get_join_new(self, join_entry, on_dict, *args,
-                     order_by=None, in_filter=None, equal_filter=None, range_filter=None,**kwargs):
+                     order_by=None, in_filter=None, equal_filter=None, range_filter=None, **kwargs):
         session = self.tr.start()
         eval_str = 'and'.join(['{}.{}=={}.{}'.format(self.entry.__name__, x, join_entry.__name__, on_dict[x]) for x in
                                on_dict])
@@ -292,7 +293,7 @@ class BaseDao(object):
         self.tr.end()
         return res
 
-    def simple_get_all(self, extra_dict=None,**kwargs):
+    def simple_get_all(self, extra_dict=None, **kwargs):
         """
         简单查询，
         :param extra_dict:
@@ -461,7 +462,7 @@ class BaseDao(object):
         sql += " ON DUPLICATE KEY UPDATE "
         temp_list = ["`" + x + "`=values(`" + x + "`)" for x in insert_keys]
         sql += ','.join(temp_list)
-        self.execute(sql,_is_direct=True)
+        self.execute(sql, _is_direct=True)
         return True
 
     def simple_update(self, update_query_condition={}, **kwargs):
@@ -488,15 +489,23 @@ class BaseDao(object):
             session.close()
             raise (e)
 
-    def execute(self, sql, *args, _is_direct=False,**kwargs):
+    def escape_sql(self, sql):
+        sql = sql.replace(":", "\\:")
+        return sql
+
+    def execute(self, sql, *args, _is_direct=False, **kwargs):
         session = self.tr.start()
         # session.begin_nested()
+        if _is_direct:
+            sql = self.escape_sql(sql)
         res = session.execute(sql, *args, **kwargs)
         self.tr.end()
         return res
 
-    def select_execute(self, sql, num=0, *args,  _is_direct=False,**kwargs):
+    def select_execute(self, sql, num=0, *args, _is_direct=False, **kwargs):
         session = self.tr.start()
+        if _is_direct:
+            sql = self.escape_sql(sql)
         res = session.execute(sql, *args, **kwargs).fetchall()
         if type(num) == int and num > 0:
             res = res[:num]
@@ -542,7 +551,7 @@ class ObjectCovertToDictDao(BaseDao):
         res = super().simple_get_all(**kwargs)
         return self.__deal_res(res)
 
-    def simple_get_all_filter(self, params, condition_type='and',  **kwargs):
+    def simple_get_all_filter(self, params, condition_type='and', **kwargs):
         res = super().simple_get_all_filter(params, condition_type=condition_type, **kwargs)
         return self.__deal_res(res)
 
@@ -550,7 +559,7 @@ class ObjectCovertToDictDao(BaseDao):
         res = super().simple_get_all(**kwargs)
         return self.__deal_res(res)
 
-    def simple_get_join(self, join_entry, on_dict, *args,order_by=None, **kwargs):
+    def simple_get_join(self, join_entry, on_dict, *args, order_by=None, **kwargs):
         res = super().simple_get_join(join_entry, on_dict, *args, order_by=order_by, **kwargs)
         return self.__deal_res(res)
 
